@@ -1,7 +1,7 @@
 package Bencher::Formatter::ScaleTime;
 
-our $DATE = '2016-06-28'; # DATE
-our $VERSION = '1.012'; # VERSION
+our $DATE = '2016-06-29'; # DATE
+our $VERSION = '1.013'; # VERSION
 
 use 5.010001;
 use strict;
@@ -27,7 +27,8 @@ sub munge_result {
     # workaround for bug RT#113117 (max sometimes undef)
     $max //= $min;
 
-    my ($unit, $factor);
+    my $unit = "";
+    my $factor = 1;
     if ($max <= 1.5e-6) {
         $unit = "ns";
         $factor = 1e9;
@@ -39,6 +40,8 @@ sub munge_result {
         $factor = 1e3;
     }
 
+    $envres->[3]{'func.time_factor'} = $factor;
+
     if ($unit) {
         for my $rit (@{$envres->[2]}) {
             $rit->{time} *= $factor;
@@ -75,7 +78,7 @@ Bencher::Formatter::ScaleTime - Scale time to make it convenient
 
 =head1 VERSION
 
-This document describes version 1.012 of Bencher::Formatter::ScaleTime (from Perl distribution Bencher-Backend), released on 2016-06-28.
+This document describes version 1.013 of Bencher::Formatter::ScaleTime (from Perl distribution Bencher-Backend), released on 2016-06-29.
 
 =for Pod::Coverage .*
 
